//////////////////////////////////////////////////////////////////////
/*!	@class	AquesTalk2 for iPhone

	@brief	規則音声合成エンジン AquesTalk2 iPhone API

	音声記号列から音声波形データを生成、または、サウンドデバイスに出力する	

	@author	N.Yamazaki (Aquest)

	@date	2010/02/10	N.Yamazaki	Creation (from AquesTalkDa.h)
    @date	2013/07/04	N.Yamazaki	音声記号列の文字コード　SJISに加えUTF8のインターフェース追加
*/
//  COPYRIGHT (C) 2010 AQUEST CORP.
//////////////////////////////////////////////////////////////////////
#if !defined(_AQUESTALK2DA_H_)
#define _AQUESTALK2DA_H_
#ifdef __cplusplus
extern "C"{
#endif

/////////////////////////////////////////////
//!	音声記号列から音声波形を生成
//!	音声波形データは内部で領域確保される。
//!	音声波形データの解放は本関数の呼び出し側でAquesTalk_FreeWave()にて行う
//! @param	koe[in]		音声記号列（SJIS NULL終端）
//! @param	koeUtf8[in]		音声記号列（UTF8 NULL終端）
//! @param	iSpeed[in]	発話速度 [%] 50-300 の間で指定 default:100
//!	@param	pSize[out]	生成した音声データのサイズ[byte]（エラーの場合はエラーコードが返る）
//!	@param	phontDat[in]	phontデータの先頭アドレスを指定します。このDLLのデフォルトPhontを用いるときは０を指定します。
//!	@return	WAVフォーマットの音声データの先頭アドレス。エラー時はNULLが返る
unsigned char * AquesTalk2_Synthe(const char *koe, int iSpeed, int *pSize, void *phontDat);
unsigned char * AquesTalk2_Synthe_Utf8(const char *koeUtf8, int iSpeed, int *pSize, void *phontDat);

/////////////////////////////////////////////
//!	音声データの領域を開放
//!	@param  wav[in]		AquesTalk_Synthe()で返されたアドレスを指定
void AquesTalk2_FreeWave(unsigned char *wav);

	
	
/////////////////////////////////////////////
//!	音声を合成してサウンドデバイスに出力（同期タイプ）
//!	音声の再生が終了するまで戻らない
//! @param	koe[in]		音声記号列（NULL終端）
//! @param	koeUtf8[in]		音声記号列（UTF8 NULL終端）
//! @param	iSpeed[in]	発話速度 [%] 50-300 の間で指定
//!	@param	phontDat[in]	phontデータの先頭アドレスを指定します。このDLLのデフォルトPhontを用いるときは０を指定します。
//!	@return	0:正常終了　それ以外：エラーコード
int  AquesTalk2Da_PlaySync(const char *koe, int iSpeed, void *phontDat); // SJIS
int  AquesTalk2Da_PlaySync_Utf8(const char *koeUtf8, int iSpeed, void *phontDat); // UTF-8



////////////////////////////////////////////////////////////////////////
//  以下、非同期タイプの関数
////////////////////////////////////////////////////////////////////////
typedef void		*H_AQTKDA;	// 音声合成エンジンのハンドル 同期タイプの関数で使用する

/////////////////////////////////////////////
//!	音声合成エンジンのインスタンスを生成（非同期タイプ）
//! @return	音声合成エンジンのハンドルを返す
H_AQTKDA  AquesTalk2Da_Create();

/////////////////////////////////////////////
//!	音声合成エンジンのインスタンスを解放（非同期タイプ）
//! @param	hMe[in]		音声合成エンジンのハンドル AquesTalk2Da_Create()で生成
void  AquesTalk2Da_Release(H_AQTKDA hMe);

/////////////////////////////////////////////
//!	音声を合成して出力（非同期タイプ）
//!	音声波形生成後に、すぐに戻る
//!	notificationを指定すると、再生終了後に指定したイベントが通知される。
//!		
//! @param	hMe[in]		音声合成エンジンのハンドル AquesTalk2Da_Create()で生成
//! @param	koe[in]		音声記号列（NULL終端）
//! @param	koeUtf8[in]		音声記号列（UTF8 NULL終端）
//! @param	iSpeed[in]	発話速度 [%] 50-300 の間で指定
//!	@param	phontDat[in]	phontデータの先頭アドレスを指定します。このDLLのデフォルトPhontを用いるときはnilを指定します。
//! @param	notification[in]	再生終了イベントの指定。イベント通知不要のときはnilを指定します。
//!	@return	0:正常終了　それ以外：エラーコード
int  AquesTalk2Da_Play(H_AQTKDA hMe, const char *koe, int iSpeed, void *phontDat, NSNotification* notification);
int  AquesTalk2Da_Play_Utf8(H_AQTKDA hMe, const char *koeUtf8, int iSpeed, void *phontDat, NSNotification* notification);

/////////////////////////////////////////////
//!	再生の中止 
//! AquesTalk2Da_Play()で再生中に、再生を中断する。
//!	再生中(再生待ちを含む）であり、かつ、notificationが指定されていたなら、
//! 再生終了イベントが通知される。
//! @param	hMe[in]		音声合成エンジンのハンドル AquesTalk2Da_Create()で生成
void  AquesTalk2Da_Stop(H_AQTKDA hMe);

/////////////////////////////////////////////
//!	再生中か否か
//! @param	hMe[in]		音声合成エンジンのハンドル AquesTalk2Da_Create()で生成
//! @return 1:再生中 0:再生中でない
int  AquesTalk2Da_IsPlay(H_AQTKDA hMe);


#ifdef __cplusplus
}
#endif
#endif // !defined(_AQUESTALK2DA_H_)
//  ----------------------------------------------------------------------
// !  Copyright AQUEST Corp. 2006- .  All Rights Reserved.                !
// !  An unpublished and CONFIDENTIAL work.  Reproduction, adaptation, or !
// !  translation without prior written permission is prohibited except   !
// !  as allowed under the copyright laws.                                !
//  ----------------------------------------------------------------------
